C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_GET_YLOW     **
C**************************
C
C
CD-Doc:
C YLOW             SUBROUTINE LDM_GET_YLOW (VALUE, IFLAG, ND)
CD-end
      SUBROUTINE LDM_GET_YLOW (VALUE, IFLAG, ND)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get value of real parameter YLOW
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      REAL VALUE
      INTEGER IFLAG
      INTEGER ND

C  VALUE     (W)   Value for 'ylow' in rasters
C  IFLAG     (W)   Flag = -1 undefined value
C                       =  0 default value
C                       =  1 value set explicitly
C                       =  2 value set globally
C ND         (W)   No. of decimal places for printing (- if E format)
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      VALUE = YLOW
      IFLAG = IS_YLOW
      ND = ND_YLOW
      IF (ND.EQ.-1000) ND = 2
      RETURN
      END
